@@ -819,7 +819,7 @@ def _head_object(context, bucket, key):
     credentials = yield context.s3_auth()
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
                              aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
-    response = s3_client.head_object(Bucket=bucket, Key=key)
+    response = yield s3_client.head_object(Bucket=bucket, Key=key)
     print('head',response)
     if 'ContentLength' in response and response['ContentLength'] >= 0:
         return True
